@@ -10,7 +10,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import six
 import yaml
 
 from django.urls import reverse
@@ -32,7 +31,7 @@ def _populate_node_params(name, profile_id, cluster_id, role, metadata):
             metadata_dict = yaml.safe_load(metadata)
         except Exception as ex:
             raise Exception(_('The specified metadata is not a valid '
-                              'YAML: %s') % six.text_type(ex))
+                              'YAML: %s') % ex)
     params = {"name": name,
               "profile_id": profile_id,
               "cluster_id": cluster_id,
@@ -86,10 +85,10 @@ class CreateForm(forms.SelfHandlingForm):
             msg = _('Creating node "%s" successfully') % data['name']
             messages.info(request, msg)
             return node
-        except Exception:
+        except Exception as e:
             redirect = reverse("horizon:cluster:nodes:index")
             exceptions.handle(request,
-                              _("Unable to create node."),
+                              _("Unable to create node: %s") % e,
                               redirect=redirect)
 
 
@@ -133,9 +132,9 @@ class UpdateNodeForm(forms.SelfHandlingForm):
                   ' has been accepted for processing.') %
                 data['name'])
             return node
-        except Exception:
+        except Exception as e:
             redirect = reverse("horizon:cluster:nodes:index")
             exceptions.handle(request,
-                              _("Unable to update node."),
+                              _("Unable to update node: %s") % e,
                               redirect=redirect)
             return False
